@@ -3,7 +3,7 @@ package XML::LibXML::Tools;
 BEGIN {
   @XML::LibXML::Tools::ISA = qw( Exporter );
   @XML::LibXML::Tools::EXPORT = qw( BEFORE AFTER TO );
-  $XML::LibXML::Tools::VERSION = '0.80';
+  $XML::LibXML::Tools::VERSION = '1.00';
 }
 
 use strict;
@@ -21,12 +21,9 @@ use constant DEEP   => 1;
 
 use Class::AccessorMaker {
   # object wide settings
-  encoding        => "ISO-8859-1",
-  toEncoding      => "UTF-8",
   defaultLocation => TO,
 
   # object holders
-  objectIconv => "",
   objectDom   => "",
   storeDom    => 1,
 
@@ -42,21 +39,6 @@ use Class::AccessorMaker {
 sub init {
   my ($self) = @_;
 
-  # XML likes UTF8 - try to make converter
-  eval "use Text::Iconv;";
-
-  if ( !$@ ) {
-    my $iconv;
-    eval {
-      local $SIG{__DIE__} = sub {};
-      $iconv = Text::Iconv->new($self->encoding,$self->toEncoding)
-    };
-
-    $iconv && do { $self->objectIconv($iconv);
-		   $self->objectIconv->raise_error(1);
-		 };
-  }
-
   $self->croakOnError($croak);
   return $self;
 }
@@ -138,6 +120,7 @@ sub complex2Dom {
 
   # create ourselves a Dom.
   my $dom = XML::LibXML::Document->new();
+  $dom->setEncoding( "utf-8" );
 
   # find root element
   my $ref = $param{data};
@@ -311,7 +294,6 @@ sub ref2TextNode {
 
   my $textNode;
   if ( ref($param{data}) !~ /XML::LibXML/ ) {
-    $param{data} = $self->convert(%param, depth => $param{depth}+1);
     $textNode = $param{dom}->createTextNode($param{data});
 
   } elsif ( ref($param{data}) =~ /DocumentFragment|Element/ ) {
@@ -380,7 +362,6 @@ sub makeXMLFragment {
     $content = $param{data};
 
   } else {
-    $param{data} = $self->convert(%param, depth => $param{depth}+1);
     $content = $param{dom}->createTextNode($param{data});
   }
 
@@ -417,16 +398,7 @@ sub domUpdate {
     my $key = shift @tmp;
 
     my $value;
-    if ( !ref($key) ) {
-      $value = shift @tmp;
-
-      if ( !ref($value) ) {
-	$value = $self->convert( %param,
-				 data => $value,
-				 depth => $param{depth}+1 );
-      }
-
-    }
+    $value = shift @tmp if ( !ref($key) );
 
     if( my $attr = isAttribute($key) ){
       # update attribute of tag
@@ -550,15 +522,7 @@ sub domAdd {
     my $key = shift @tmp;
 
     my $value;
-    if ( !ref($key) ) {
-
-      $value = shift @tmp;
-      if  ( !ref($value) ) {
-	$value = $self->convert( %param,
-				 data => $value,
-				 depth => $param{depth}+1 );
-      }
-    }
+    $value = shift @tmp if ( !ref($key) );
 
     if ( my $attr = isAttribute($key) ) {
       # update attribute of tag
@@ -739,49 +703,6 @@ sub domDelete {
 #   USEFULL TOOLS?
 # ==========================================================================
 
-sub getConverter {
-  my $self  = shift;
-  my %param = @_;
-
-  $param{encoding} ||= '';
-  if ( $param{encoding} eq $self->toEncoding ) {
-    return undef;
-  }
-
-  my $iconv;
-  if ( $param{encoding} ne $self->encoding ) {
-    eval {
-      local $SIG{__DIE__} = sub {};
-      $iconv = Text::Iconv->new($param{encoding}, $self->toEncoding)
-    };
-  }
-
-  return $iconv || $self->objectIconv;
-}
-
-sub convert {
-  my $self  = shift;
-  my %param = @_;
-
-  # if noConvert is on return instantly.
-  return $param{data} if $param{noConvert};
-
-  my $prev = $self->showPath;
-  $self->showPath($param{showpath}) if exists $param{showpath};
-  warn "-" x $param{depth}, "convert\n" if $self->showPath;
-
-  # convert if you can.
-  my $iconv = $self->getConverter(%param);
-  $param{data} = '' if not defined $param{data};
-
-  if  ( $iconv ) {
-    $param{data} = $iconv->convert($param{data});
-  }
-
-  $self->showPath($prev);
-  return $param{data};
-}
-
 sub analyseXpath {
   my ( $self, $xpath ) = @_;
 
@@ -913,8 +834,6 @@ XML::LibXML::Tools - An API for easy XML::LibXML DOM manipulation
 Hands an interface for merging, updating, adding and deleting a
 L<XML::LibXML::Document> in an easy fashion.
 
-Takes care of encoding, etc.
-
 =head1 CONSTANTS
 
 Constants are exported for your ease.
@@ -930,26 +849,10 @@ All these constants can be used for the location parameter
 
 Methods are all accessors, they are show with their default value.
 
-=head2 encoding ( "ISO-8859-1" )
-
-  Default input encoding.
-  Overwritten by the encoding parameter for each function.
-
-=head2 toEncoding ( "UTF-8" )
-
-  Default to-encoding
-  Never overwritten.
-
 =head2 defaultLocation ( TO )
 
   Default adding location.
 
-=head2 objectIconv ( bless({},"Text::Iconv") )
-
-  Not really relevant, but availabe:
-
-  Text::Iconv->new(encoding, toEncoding)
-
 =head2 objectDom ( "" )
 
   Filled by complex2Dom if not yet defined, or you.
@@ -1022,17 +925,6 @@ parameters.
   The data for the operation. Can be an intrigate combination of
   arrays DOMs and NodeLists
 
-=head2 encoding => "UTF-7"
-
-  The from-encoding the be used in this operation
-
-=head2 noConvert => 0, 1
-
-  Do not convert the data from one encoding to the other for this
-  operation.
-
-  !! USE AT OWN RISK !!
-
 =head2 location => TO
 
 =head2 location => BEFORE
@@ -1073,6 +965,8 @@ All these functions return undef once an error has been raised.
     Turns an array reference into a L<XML::LibXML::Document>, taking
     array->[0] as the rootname. calls array2Dom for this purpose.
 
+    The newly created DOM's encoding is set to be UTF-8
+
 =head2 array2Dom ( %params )
 
   DESCRIPTION
@@ -1118,11 +1012,6 @@ All these functions return undef once an error has been raised.
 
   returns 'parot', 2, '/newlsetter[1]/section[2]'
 
-=head2 convert ( %params )
-
-  DESCRIPTION
-    converts *data using L<Text::Iconv>. Is influenced by *encoding and *noConvert
-
 =head2 attribute ( "name", "value" )
 
   returns the special attribute notation for arrays which need to be
@@ -1158,6 +1047,11 @@ L<XML::LibXML>
 
 =head1 KNOWN ISSUES
 
+  - Encoding:
+
+    + It is expected that you supply your data in the same encoding as
+      is your DOM.
+
   - Unfixed checking problem.
     You might see something like: complex2Dom: To complex! ...
 
